==> gs2-cdk-1.0.87.tar.gz: gs2-cdk-1.0.87/src/gs2_cdk/ranking2/model/__init__.py <==
# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from .Namespace import Namespace
from .options.NamespaceOptions import NamespaceOptions
from .GlobalRankingModel import GlobalRankingModel
from .options.GlobalRankingModelOptions import GlobalRankingModelOptions
from .enum.GlobalRankingModelOrderDirection import GlobalRankingModelOrderDirection
from .enum.GlobalRankingModelRewardCalculationIndex import GlobalRankingModelRewardCalculationIndex
from .ClusterRankingModel import ClusterRankingModel
from .options.ClusterRankingModelOptions import ClusterRankingModelOptions
from .enum.ClusterRankingModelClusterType import ClusterRankingModelClusterType
from .enum.ClusterRankingModelOrderDirection import ClusterRankingModelOrderDirection
from .enum.ClusterRankingModelRewardCalculationIndex import ClusterRankingModelRewardCalculationIndex
from .SubscribeRankingModel import SubscribeRankingModel
from .options.SubscribeRankingModelOptions import SubscribeRankingModelOptions
from .enum.SubscribeRankingModelOrderDirection import SubscribeRankingModelOrderDirection
from .RankingReward import RankingReward
from .options.RankingRewardOptions import RankingRewardOptions
from .VerifyActionResult import VerifyActionResult
from .options.VerifyActionResultOptions import VerifyActionResultOptions
from .ConsumeActionResult import ConsumeActionResult
from .options.ConsumeActionResultOptions import ConsumeActionResultOptions
from .AcquireActionResult import AcquireActionResult
from .options.AcquireActionResultOptions import AcquireActionResultOptions
from .TransactionResult import TransactionResult
from .options.TransactionResultOptions import TransactionResultOptions
from .CurrentMasterData import CurrentMasterData

==> gs2-cdk-1.0.109.tar.gz: gs2-cdk-1.0.109/src/gs2_cdk/ranking2/model/__init__.py <==
# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from .Namespace import Namespace
from .options.NamespaceOptions import NamespaceOptions
from .GlobalRankingModel import GlobalRankingModel
from .options.GlobalRankingModelOptions import GlobalRankingModelOptions
from .enums.GlobalRankingModelOrderDirection import GlobalRankingModelOrderDirection
from .enums.GlobalRankingModelRewardCalculationIndex import GlobalRankingModelRewardCalculationIndex
from .ClusterRankingModel import ClusterRankingModel
from .options.ClusterRankingModelOptions import ClusterRankingModelOptions
from .enums.ClusterRankingModelClusterType import ClusterRankingModelClusterType
from .enums.ClusterRankingModelOrderDirection import ClusterRankingModelOrderDirection
from .enums.ClusterRankingModelRewardCalculationIndex import ClusterRankingModelRewardCalculationIndex
from .SubscribeRankingModel import SubscribeRankingModel
from .options.SubscribeRankingModelOptions import SubscribeRankingModelOptions
from .enums.SubscribeRankingModelOrderDirection import SubscribeRankingModelOrderDirection
from .RankingReward import RankingReward
from .options.RankingRewardOptions import RankingRewardOptions
from .VerifyActionResult import VerifyActionResult
from .options.VerifyActionResultOptions import VerifyActionResultOptions
from .ConsumeActionResult import ConsumeActionResult
from .options.ConsumeActionResultOptions import ConsumeActionResultOptions
from .AcquireActionResult import AcquireActionResult
from .options.AcquireActionResultOptions import AcquireActionResultOptions
from .TransactionResult import TransactionResult
from .options.TransactionResultOptions import TransactionResultOptions
from .CurrentMasterData import CurrentMasterData
